#!/bin/bash
#
# Author: SAKIMA Kimihisa
# Contact: sakima@hooktail.org
# Date: $Date: 2005-07-24 11:30:31 $
#
#
# Warning
#   このファイルはかならず UTF-8 文字コードで保存のこと
#   You must store this file in UTF-8 character set.
#
# 名称
#   kagipdfTex.sh - 標準入力からのLaTeXファイルを処理
#
# 書式
#   kagipdfTex.sh [OPTION] < FILE
#
# オプション
#
#
# 解説
#   いろいろチカンします
#
# ToDo
#   * オプションによりレイアウトを切り替え可能にする
#   * レイアウトは，一貫性のある仕様に基づいた
#     スキンファイルにより拡張可能とする
#
############################################################
CMDNAME=`basename $0`
USAGE="Usage: $CMDNAME [OPTION] [FILE]"


###
### USER SETTINGS
###

DOCUMENTCLASS="jsarticle"
DOCUMENTOPTIONS="11pt,a4paper"

#DOCUMENTCLASS="jsbook"
#DOCUMENTOPTIONS="11pt,a4paper,report"



###
### オプション処理
###

EUC=TRUE
SJIS=FALSE
UTF=FALSE
OPT=
while getopts esu OPT
do
  case $OPT in
    e)  EUC=TRUE
        ;;
    s)  SJIS=TRUE
        EUC=FALSE
        ;;
    u)  UTF=TRUE
        EUC=FALSE
        ;;
    /?) echo "$USAGE" 1>&2
        exit 1
        ;;
  esac
done
shift `expr $OPTIND - 1`



###
### sed と ruby で編集（改行コードを扱うときはruby）
###

# ドキュメントクラスを置換
sed -e "s/\\\\documentclass.*/\\\\documentclass\[$DOCUMENTOPTIONS\]{$DOCUMENTCLASS}/" |


# color, graphicx パッケージに対して dvipdfm オプションを追加
sed -e 's/\\usepackage{color}/\\usepackage\[dvipdfm\]{color}/' \
    -e 's/\\usepackage{graphicx}/\\usepackage\[dvipdfm\]{graphicx}/' |


# あると困るパッケージ命令を削除
ruby -pe 'sub(/\\usepackage\[DIV12\]\{typearea\}\n/) { "" }' \
     -pe 'sub(/\\usepackage\{ae\}\n/) { "" }' \
     -pe 'sub(/\\usepackage\[.*\]\{inputenc\}\n/) { "" }' \
     -pe 'sub(/\\usepackage\{babel\}\n/) { "" }' \
     -pe 'sub(/\\usepackage\{aeguill\}\n/) { "" }'|


# amssymb, bm パッケージを追加
ruby -pe 'sub(/\\usepackage\{amsmath\}/) { "\\usepackage\{amsmath,amssymb,bm\}" }' |

# utf, otf パッケージを追加する場合
#ruby -pe 'sub(/\\usepackage\{amsmath\}/) { "\\usepackage\{amsmath,amssymb,bm\}\n\\usepakage\{utf,otf\}" }' |

# hyperref パッケージのオプションを変更
ruby -pe 'sub(/\\usepackage\[(colorlinks=true,linkcolor=blue,urlcolor=blue)\]\{hyperref\}/)\
          { "\\usepackage\[dvipdfm,bookmarks=true," +
             $1 +
             "\]\{hyperref\}" +
             "\n\\ifnum 42146=\\euc\"A4A2 \\AtBeginDvi\{\\special\{pdf:tounicode EUC-UCS2\}\}\\else" +
             "\n\\AtBeginDvi\{\\special\{pdf:tounicode 90ms-RKSJ-UCS2\}\}\\fi" }' |


# 行頭の全角スペースを取り除く
sed -e 's/^　//' |


# 「、」を「，」に，「。」を「．」に置換
sed -e 's/、/，/g' \
    -e 's/。/．/g' |


# プリアンブルにいろいろ追加
sed -e 's/\\newlength{\\admonitionwidth}/\
%% ページサイズ調整\
\\setlength{\\textwidth}{\\fullwidth}\
\\setlength{\\textheight}{39\\baselineskip}\
\\addtolength{\\textheight}{\\topskip}\
\\setlength{\\voffset}{-0.5in}\
\\setlength{\\headsep}{0.3in}\
\
%% ページスタイル\
\\usepackage{fancyhdr}\
\\pagestyle{fancy}\
\\let\\origtitle\\title \
\\renewcommand{\\title}[1]{\\lhead{\\footnotesize #1}\\origtitle{#1}}\
\\rhead{\\thepage}\
\\cfoot{}\
\\rfoot{\\footnotesize --- {\\sf 物理のかぎしっぽ\\ \\ \\texttt{http:\/\/www12.plala.or.jp\/ksp\/}} ---}\
%\\renewcommand{\\headrulewidth}{0.3pt}\
%\\renewcommand{\\footrulewidth}{0.0pt}\
\
%% section見出しの再定義\
%\\makeatletter\
%\\renewcommand{\\section}{%\
%  \\@startsection{section}% #1 見出し\
%   {1}% #2 見出しのレベル\
%   {\\z@}% #3 横組みの場合，見出し左の空き(インデント量)\
%   {1.4\\Cvs \\@plus.5\\Cdp \\@minus.2\\Cdp}% #4 見出し上の空き\
%   {.5\\Cvs \\@plus.3\\Cdp}% #5 見出し下の空き (負の値なら見出し後の空き) \
%   {\\reset@font\\Large\\bfseries}% #6 見出しの属性\
%}%\
%\\makeatother\
\
%% section見出しの再定義\
\\definecolor{specialcolor}{cmyk}{.80,.67,.26,.13}\
\\makeatletter\
\\def\\section{\\secdef\\@section\\@ssection}\
\\def\\@ssection{\\@testopt{\\@makesectionhead{}}{}}\
\\def\\@section{%\
   \\refstepcounter{section}%\
   \\@makesectionhead{\\thesection}}\
\\def\\@makesectionhead#1[#2]#3{%\
   \\if@noskipsec \\leavevmode \\fi\
   \\ifhmode \\unskip\\par \\fi\
   \\vskip2\\baselineskip\
   \\vspace*\\z@\
   \\setbox\\z@\\hbox to\\hsize{%\
     \\hbox to\\textwidth{%\
       \\vrule \\@height-8\\p@ \\@depth8\\p@ \\@width\\textwidth\
     \\dimen@\\textwidth\
     \\advance\\dimen@5mm\
       \\kern-\\dimen@\
       \\Large\
       \\hbox to0mm{\\bfseries\\hss #1}\\kern5.0mm\
       {\\color{specialcolor}%\
         \\vrule\\@width2.7mm \\@depth8\\p@ \\@height17\\p@}%\
       \\kern2.5mm\
       \\gtfamily #3\\hfil}%\
     \\hss}%\
   \\ht\\z@\\Cht \\dp\\z@\\Cdp \\box\\z@\
   \\nobreak \\vskip1\\baselineskip\
   \\@afterindenttrue \\@afterheading\
   \\sectionmark{#2}%\
   \\addcontentsline{toc}{section}{\\numberline{#1}#2}}\
\\makeatother\
\
%% caption命令で「図1」などを出さないようにする\
\\makeatletter\
\\long\\def\\@makecaption#1#2{%\
  \\vskip\\abovecaptionskip\
  \\iftdir\\sbox\\@tempboxa{#1\\hskip1zw#2}%\
    \\else\\sbox\\@tempboxa{#2}%\
  \\fi\
  \\ifdim \\wd\\@tempboxa >\\hsize% \
    \\iftdir #1\\hskip1zw#2\\relax\\par\
      \\else #2\\relax\\par\\fi%\
  \\else\
    \\global \\@minipagefalse\
    \\hbox to\\hsize{\\hfil\\box\\@tempboxa\\hfil}\
  \\fi\
  \\vskip\\belowcaptionskip}\
\\makeatother\
\
%% Docutils デフォルト\
\\newlength{\\admonitionwidth}/' |


# 画像スケールを縮小，いつでも中央に配置
sed -e 's/\\includegraphics/\\includegraphics[scale=0.55]/g' \
    -e 's/\\includegraphics\(.*}$\)/\\begin{center}\\includegraphics\1\\end{center}/g' |


# TeXファイル中の author を置換
ruby -pe 'gsub(/\\author\{(.*?)\}/) { "\\author\{" + $1 + "＠物理のかぎプロジェクト\}" }' \
     -pe 'gsub(/pdfauthor=\{(.*?)\}/) { "pdfauthor=\{" + $1 + "＠物理のかぎプロジェクト\}" }' |


# \end{quote} ，\end{itemize} の後の改行を取り除く
ruby -pe 'gsub(/(\\end\{quote\}).*?\n/) { $1 }' \
     -pe 'gsub(/(\\end\{itemize\}).*?\n/) { $1 }'
